emailservices/emailstore/base_plugin/src/basepluginparts.cpp
changeset 75 47d84de1c893
parent 72 64e38f08e49c
--- a/emailservices/emailstore/base_plugin/src/basepluginparts.cpp	Fri Sep 17 08:27:21 2010 +0300
+++ b/emailservices/emailstore/base_plugin/src/basepluginparts.cpp	Mon Oct 04 00:05:37 2010 +0300
@@ -253,16 +253,21 @@
 
 
 /**
  * The method will leave with KErrNotSupported if the msgstore is encrypted.
  */
 EXPORT_C TInt CBasePlugin::GetMessagePartFileL(
     const TFSMailMsgId& aMailBoxId,
     const TFSMailMsgId& /*aParentFolderId*/,
     const TFSMailMsgId& aMessageId,
     const TFSMailMsgId& aMessagePartId,
-    RFile& aFileHandle )
+    RFile& aFileHandle,
+    TBool aForWriting)
 
     {
+    if (aForWriting)
+        {
+        return KErrNotSupported;
+        }
     CMailboxInfo& mailBox = GetMailboxInfoL( aMailBoxId.Id() );
     
     CMsgStoreMessage* msg = mailBox().FetchMessageL( aMessageId.Id(), KMsgStoreInvalidId );
@@ -253,16 +253,21 @@
 
 /**
- * The method will leave with KErrNotSupported if the msgstore is encrypted.
+ * The method will leave with KErrNotSupported if the msgstore is encrypted or if trying to open the file for writing.
  */
 EXPORT_C TInt CBasePlugin::GetMessagePartFileL(